Work order

Order Number:: | 00666
Equipment: | Description
Description: | Test equipment
Client: | Client
Phone: |  | Cell Phone: |
Estimated cost: | $299.00 | Estimated start: | 01/01/13 | Estimated finish: | 01/05/13

Code | Item | Quantity | Price | Total
| Description | 1 | $10.00 | $10.00
Total: | $10.00

Quote:

    This is the defect detected

Client signature
Client
Responsible signature
Quote responsible